@@ -66,9 +66,9 @@ class Residual(nn.Module):
 
         return y + x
 
-# rotary positional embedding
+# rotary positional embedding w/ xpos
 # https://arxiv.org/abs/2104.09864
-
+# https://arxiv.org/abs/2212.10554v1
 
 class RotaryEmbedding(nn.Module):
     def __init__(self, dim, scale_base = 512):
@@ -85,7 +85,7 @@ class RotaryEmbedding(nn.Module):
         freqs = torch.einsum('i , j -> i j', t, self.inv_freq)
         freqs = torch.cat((freqs, freqs), dim = -1)
 
-        power = (torch.arange(seq_len, device = device) - (seq_len // 2)) / self.scale_base
+        power = (t - (seq_len // 2)) / self.scale_base
         scale = self.scale ** rearrange(power, 'n -> n 1')
         scale = torch.cat((scale, scale), dim = -1)
 
